pystagram.graph_api.endpoints.me package — pystagram 0.1 documentation

# pystagram.graph_api.endpoints.me package

## Submodules

## pystagram.graph_api.endpoints.me.accounts module

class pystagram.graph_api.endpoints.me.accounts.Accounts(me: Me)

  Bases: `object`

  The Accounts node of the Instagram Graph API.

  Parameters:

    me (`Me`) – An instance of the `Me` class.

  get(fields: List[str | AccountFields] | None = None, access_token: str | None = None)

    Get fields and edges on the facebook User accounts whose User Access Token is being used in the query. This endpoint translates to GET /{user-id}/accounts, based on the User ID identified by the access token used in the query.

    Parameters:

      - fields (Optional[List[Union[str, AccountFields]]], optional) – A list of `pystagram.graph_api.components.fields.account_fields.AccountFields` to get from the Accounts node, defaults to None

      - access_token (str, optional) – The access token of the Instagram user, inferred from the InstagramGraphApi instance if None, defaults to None

    Returns:

      The response from the GET /me/accounts endpoint.

    Return type:

      `pystagram.helpers.api_client.api_response.InstagramApiResponse`

## pystagram.graph_api.endpoints.me.me module

class pystagram.graph_api.endpoints.me.me.Me(graph_api: GraphInstagramBaseApi)

  Bases: `object`

  The Me node of the Instagram Graph API.

  Parameters:

    graph_api (`InstagramGraphApi`) – An instance of the `InstagramGraphApi` class.

  property accounts

    The Account node of the Instagram Graph API. See the `pystagram.graph_api.endpoints.me.accounts.Accounts` class for additional details.

  get(fields: List[str | MeFields] | None = None, access_token: str | None = None)

    Get fields and edges on the User whose User Access Token is being used in the query. This endpoint translates to GET /{user-id}, based on the User ID identified by the access token used in the query.

    Parameters:

      - fields (Optional[List[Union[str, MeFields]]], optional) – A list of `pystagram.graph_api.components.fields.me_fields.MeFields` to get from the User node, defaults to None

      - access_token (str, optional) – The access token of the Instagram user, inferred from the InstagramGraphApi instance if None, defaults to None

    Returns:

      The response from the GET /me endpoint.

    Return type:

      `pystagram.helpers.api_client.api_response.InstagramApiResponse`

## Module contents